@@ -25,7 +25,7 @@
 #' @param class Category for classification, a factor level, or a number indicating which factor level.
 #' @param predictFun Function of (fit, data) to extract numeric predictions from fit. Uses condvis2::CVpredict by default, which works for many fit classes.
 #' @param normalized Should Friedman's H-statistic be normalized or not. Default is FALSE.
-#' @param numPerm Number of permutations to preform. Default is 4.
+#' @param numPerm Number of permutations to perform for agnostic importance. Default is 4.
 #' @param showVimpError Logical. If TRUE, and `numPerm > 1` then a tibble containing the variable names, their importance values,
 #' and the standard error for each importance is printed to the console.
 #' @return A matrix of interaction values, with importance on the diagonal.
@@ -187,12 +187,14 @@ vividImportance <- function(fit, data, response = NULL,
                             importanceType = NULL,
                             predictFun = NULL,
                             numPerm = 4,
-                            showVimpError = FALSE, ...) {
+                            showVimpError = FALSE,
+                            ...) {
   if (importanceType == "agnostic") {
     vividImportance.default(fit, data, response = response,
                             predictFun = predictFun,
                             numPerm = 4,
-                            showVimpError = FALSE, ...)
+                            showVimpError = FALSE,
+                            ...)
   } else {
     UseMethod("vividImportance", fit)
   }
@@ -202,14 +204,16 @@ vividImportance <- function(fit, data, response = NULL,
 
 
 # Default flashlight ------------------------------------------------------
-
+#' @export
+#' @method vividImportance default
 vividImportance.default <- function(fit,
                                     data,
                                     response = NULL,
                                     importanceType = NULL,
                                     predictFun = NULL,
                                     numPerm = 4,
-                                    showVimpError = FALSE) {
+                                    showVimpError = FALSE,
+                                    ...) {
   message("Agnostic variable importance method used.")
 
 
@@ -223,27 +227,25 @@ vividImportance.default <- function(fit,
   )
 
 
-
-
-  # extract importance
+  # Extract importance
   suppressWarnings(
     imp <- light_importance(fl, m_repetitions = numPerm)
   )
+  # Column names and order in imp$data:
+  #   label  metric  variable  value  error  (flashlight < 1.0.0)
+  #   label_ metric_ variable_ value_ error_ (flashlight >=1.0.0)
+  impDf <- imp$data[, 3:5]
+  names(impDf) <- c('Variable', 'Importance', 'Std_Error')
 
-  if(showVimpError){
-    impDf <- imp$data[,c(3:5)]
-    names(impDf) <- c('Variable', 'Importance', 'Std_Error')
+  if(showVimpError) {
     print(impDf)
   }
 
-
-
-  importance <- imp$data[, 3:4]
-  if (any(is.nan(importance$value))) {
-    importance$value <- 1
+  if (any(is.nan(impDf$Importance))) {
+    impDf$Importance <- 1
     message("Flashlight importance works for numeric and numeric binary response only; setting importance to 1.")
   }
-  importance <- setNames(importance$value, as.character(importance$variable)) # turn into named vector
+  importance <- setNames(impDf$Importance, as.character(impDf$Variable)) # turn into named vector
 
   return(importance)
 }
@@ -251,14 +253,16 @@ vividImportance.default <- function(fit,
 
 
 # ranger ----------------------------------------------------------------
-
+#' @export
+#' @method vividImportance ranger
 vividImportance.ranger <- function(fit,
                                    data,
                                    response = NULL,
                                    importanceType = NULL,
                                    predictFun = NULL,
                                    numPerm = 4,
-                                   showVimpError = FALSE) {
+                                   showVimpError = FALSE,
+                                   ...) {
   # If no importance mode selected, then default! Else, extract importance type
   if (fit$importance.mode == "none") {
     message("No variable importance mode selected.")
@@ -281,14 +285,16 @@ vividImportance.ranger <- function(fit,
 
 
 # randomForest ------------------------------------------------------------
-
+#' @export
+#' @method vividImportance randomForest
 vividImportance.randomForest <- function(fit,
                                          data,
                                          response = NULL,
                                          importanceType = NULL,
                                          predictFun = NULL,
                                          numPerm = 4,
-                                         showVimpError = FALSE) {
+                                         showVimpError = FALSE,
+                                         ...) {
   fitImp <- dim(fit$importance)
   importanceData <- randomForest::importance(fit, scale = FALSE)
   st <- colnames(importanceData)
@@ -332,14 +338,16 @@ vividImportance.randomForest <- function(fit,
 
 
 # mlr3 learner ------------------------------------------------------------
-
+#' @export
+#' @method vividImportance Learner
 vividImportance.Learner <- function(fit,
                                     data,
                                     response = NULL,
                                     importanceType = NULL,
                                     predictFun = NULL,
                                     numPerm = 4,
-                                    showVimpError = FALSE) {
+                                    showVimpError = FALSE,
+                                    ...) {
   # if no importance mode selected, use default
   if (fit$packages == "ranger" && fit$model$importance.mode == "none") {
     message("No variable importance mode selected.")
@@ -375,13 +383,16 @@ vividImportance.Learner <- function(fit,
 
 
 # mlr original ------------------------------------------------------------
+#' @export
+#' @method vividImportance WrappedModel
 vividImportance.WrappedModel <- function(fit,
                                          data,
                                          response = NULL,
                                          importanceType = NULL,
                                          predictFun = NULL,
                                          numPerm = 4,
-                                         showVimpError = FALSE) {
+                                         showVimpError = FALSE,
+                                         ...) {
   data <- as.data.frame(data)
 
   # get data names without response
@@ -424,6 +435,8 @@ vividImportance.WrappedModel <- function(fit,
 
 
 # tidyModels --------------------------------------------------------------
+#' @export
+#' @method vividImportance model_fit
 
 vividImportance.model_fit <- function(fit,
                                       data,
@@ -431,7 +444,8 @@ vividImportance.model_fit <- function(fit,
                                       importanceType = NULL,
                                       predictFun = NULL,
                                       numPerm = 4,
-                                      showVimpError = FALSE) {
+                                      showVimpError = FALSE,
+                                      ...) {
   vImp <- vip::vi_model(fit, type = importanceType)
   vImp <- vImp[, 1:2]
   importance <- vImp$Importance
@@ -467,7 +481,8 @@ vividInteraction <- function(fit,
 
 
 # default flashlight interactions -----------------------------------------
-
+#' @export
+#' @method vividInteraction default
 vividInteraction.default <- function(fit,
                                      data,
                                      response = NULL,
@@ -475,7 +490,8 @@ vividInteraction.default <- function(fit,
                                      nmax = 500,
                                      gridSize = 50,
                                      predictFun = NULL,
-                                     normalized = FALSE) {
+                                     normalized = FALSE,
+                                     ...) {
   message("Calculating interactions...")
 
   classif <- is.factor(data[[response]]) | inherits(fit, "LearnerClassif")
@@ -511,14 +527,21 @@ vividInteraction.default <- function(fit,
     normalize = normalized, n_max = nmax
   )$data
 
+  # Column names and order in res:
+  #   label  variable  value  error  (flashlight < 1.0.0)
+  #   label_ variable_ value_ error_ (flashlight >=1.0.0)
+
+  variable <- res[[2L]]
+  value <- res[[3L]]
+
   # reorder
-  res[["variable"]] <- reorder(res[["variable"]], res[["value"]])
+  variable <- reorder(variable, value)
 
   # create matrix of values
-  vars2 <- t(simplify2array(strsplit(as.character(res[["variable"]]), ":"))) # split/get feature names
+  vars2 <- t(simplify2array(strsplit(as.character(variable), ":"))) # split/get feature names
   mat <- matrix(0, length(ovars), length(ovars)) # create matrix
   rownames(mat) <- colnames(mat) <- ovars # set names
-  mat[vars2] <- res[["value"]] # set values
+  mat[vars2] <- value # set values
   mat[lower.tri(mat)] <- t(mat)[lower.tri(mat)]
   return(mat)
 }
